from typing import Literal

agent_roles = Literal[
    "supervisor",
    "director",
    "boss",
    "generator",
    "evaluator",
    "revisor",
    "worker",
    "manager",
    "team-leader",
    "team-manager",
    "team-lead",
    "researcher",
    "analyst",
    "architect",
    "developer",
    "tester",
    "qa",
    "designer",
    "product-owner",
    "scrum-master",
    "coordinator",
    "mentor",
    "trainer",
    "consultant",
    "specialist",
    "expert",
    "strategist",
    "planner",
    "executor",
    "reviewer",
    "auditor",
]


# print(agent_roles)
